@@ -2,6 +2,8 @@ from os import path
 import urlparse
 from itertools import chain
 from bundle import Bundle
+from cache import get_cache
+from updater import get_updater
 
 
 __all__ = ('Environment', 'RegisterError')
@@ -89,6 +91,9 @@ class BaseEnvironment(object):
     def __getitem__(self, name):
         return self._named_bundles[name]
 
+    def __contains__(self, name):
+        return name in self._named_bundles
+
     def __len__(self):
         return len(self._named_bundles) + len(self._anon_bundles)
 
@@ -165,11 +170,14 @@ class BaseEnvironment(object):
     def set_cache(self, enable):
         self.config['cache'] = enable
     def get_cache(self):
-        return self.config['cache']
+        cache = get_cache(self.config['cache'], self)
+        if cache != self.config['cache']:
+            self.config['cache'] = cache
+        return cache
     cache = property(get_cache, set_cache, doc=
     """Controls the behavior of the cache. The cache will speed up rebuilding
     of your bundles, by caching individual filter results. This can be
-    particulary useful while developing, if your bundles would otherwise take
+    particularly useful while developing, if your bundles would otherwise take
     a long time to rebuild.
 
     Possible values are:
@@ -190,7 +198,10 @@ class BaseEnvironment(object):
     def set_updater(self, updater):
         self.config['updater'] = updater
     def get_updater(self):
-        return self.config['updater']
+        updater = get_updater(self.config['updater'])
+        if updater != self.config['updater']:
+            self.config['updater'] = updater
+        return updater
     updater = property(get_updater, set_updater, doc=
     """Controls when and if bundles should be automatically rebuilt.
     Possible values are:
@@ -206,17 +217,15 @@ class BaseEnvironment(object):
           Rebuild bundles if the source file timestamp exceeds the existing
           output file's timestamp.
 
-      ``"interval"``
-          Always rebuild after an interval of X seconds has passed.
-          Specify as a tuple: ``("internal", 3600)``.
-
       ``"always"``
           Always rebuild bundles (avoid in production environments).
 
-    For most people, the default value will make a lot of sense. However,
-    if you want to avoid the request which causes a rebuild taking too
-    long, you may want to disable auto-rebuilds and instead rebuild
-    yourself, outside of your webserver process.
+    For most people, the default value will be fine. However, on busy
+    websites you may want to disable automatic rebuilding, since the
+    updater will need to check for changes during every request.
+
+    Your build taking very long is another reason why you may want to
+    do it outside of the request handling process.
     """)
 
     def set_expire(self, expire):
@@ -279,6 +288,24 @@ class BaseEnvironment(object):
             return filename
         return path.abspath(path.join(self.directory, filename))
 
+    def _normalize_source_path(self, spath):
+        """Called once for every source item processed by a Bundle.
+
+        It is supposed to return the absolute path to the file, or
+        raise an exception. It is primarily intended as a hook for
+        third party integration libraries to provide support for
+        virtual paths (like Flask Blueprints, or Django staticfiles).
+
+        The function is not called for urls. It is also currently
+        not called for paths that use glob patterns, meaning those
+        cannot be virtualized at this point (TODO: See if we can
+        do something about this).
+        """
+        spath = self.abspath(spath)
+        if not path.exists(spath):
+            raise IOError("'%s' does not exist" % spath)
+        return spath
+
 
 class DictConfigStorage(ConfigStorage):
     """Using a lower-case dict for configuration values.
@@ -306,4 +333,4 @@ class Environment(BaseEnvironment):
     def __init__(self, directory, url, **more_config):
         super(Environment, self).__init__(**more_config)
         self.directory = directory
-        self.url = url
\ No newline at end of file
+        self.url = url
