@@ -42,7 +42,7 @@ class AssetsExtension(Extension):
 
         # parse the arguments
         first = True
-        while parser.stream.current.type is not 'block_end':
+        while parser.stream.current.type != 'block_end':
             if not first:
                 parser.stream.expect('comma')
             first = False
@@ -158,4 +158,4 @@ class Jinja2Loader(GlobLoader):
         else:
             raise LoaderError('Jinja parser failed on %s, tried %d environments' % (
                 filename, len(self.jinja2_envs)))
-        return False
\ No newline at end of file
+        return False
