@@ -4,11 +4,14 @@ contents (think minification, compression).
 
 import os, subprocess
 import inspect
+from webassets.exceptions import FilterError
+from webassets.importlib import import_module
 
 
 __all__ = ('Filter', 'CallableFilter', 'get_filter', 'register_filter',)
 
 
+
 class NameGeneratingMeta(type):
     """Metaclass that will generate a "name" attribute based on the
     class name if none is given.
@@ -121,7 +124,7 @@ class Filter(object):
         return False
 
     def id(self):
-        """Unique identifer for the filter instance.
+        """Unique identifier for the filter instance.
 
         Among other things, this is used as part of the caching key.
         It should therefore not depend on instance data, but yield
@@ -164,6 +167,7 @@ class CallableFilter(Filter):
     """
 
     def __init__(self, callable):
+        super(CallableFilter, self).__init__()
         self.callable = callable
 
     def unique(self):
@@ -196,8 +200,9 @@ class JavaMixin(object):
             stderr=subprocess.PIPE)
         stdout, stderr = proc.communicate(_in.read())
         if proc.returncode:
-            raise Exception('%s: subprocess returned a '
-                'non-success result code: %s' % (self.name, proc.returncode))
+            raise FilterError('%s: subprocess returned a '
+                'non-success result code: %s, stdout=%s, stderr=%s' % (
+                     self.name, proc.returncode, stdout, stderr))
             # stderr contains error messages
         else:
             out.write(stdout)
@@ -263,7 +268,7 @@ def load_builtin_filters():
 
         module_name = 'webassets.filter.%s' % name
         try:
-            module = __import__(module_name, {}, {}, [''])
+            module = import_module(module_name)
         except Exception, e:
             warnings.warn('Error while loading builtin filter '
                           'module \'%s\': %s' % (module_name, e))
