@@ -1,5 +1,5 @@
-﻿from webassets.filter import Filter
-
+﻿from __future__ import absolute_import
+from webassets.filter import Filter
 
 __all__ = ('CleverCSSFilter',)
 
@@ -19,4 +19,4 @@ class CleverCSSFilter(Filter):
         self.clevercss = clevercss
 
     def output(self, _in, out, **kw):
-        out.write(self.clevercss.convert(_in.read()))
\ No newline at end of file
+        out.write(self.clevercss.convert(_in.read()))
