@@ -26,13 +26,12 @@ See:
     http://groups.google.com/group/compass-users/browse_thread/thread/daf55acda03656d1
 """
 
-
-import time
 import os, subprocess
 from os import path
 import tempfile
 import shutil
 
+from webassets.exceptions import FilterError
 from webassets.filter import Filter
 
 
@@ -45,16 +44,26 @@ class CompassFilter(Filter):
 
     Requires at least version 0.10.
 
-    To compile a standard compass project, you only need to have
-    django-assets compile your main ``screen.sass``, ``print.sass``
-    and ``ie.sass`` files. All the partials that you include will
-    be handled by compass.
+    To compile a standard Compass project, you only need to have
+    to compile your main ``screen.sass``, ``print.sass`` and ``ie.sass``
+    files. All the partials that you include will be handled by Compass.
 
     If you want to combine the filter with other CSS filters, make
     sure this one runs first.
 
     **Note**: Currently, this needs to be the very first filter
     applied. Changes by filters that ran before will be lost.
+
+    Supported configuration options:
+
+    COMPASS_BIN
+        The path to the Compass binary. If not set, the filter will
+        try to run ``compass`` as if it's in the system path.
+
+    COMPASS_PLUGINS
+        Compass plugins to use. This is equivalent to the ``--require``
+        command line option of the Compass. and expects a Python list
+        object of Ruby libraries to load.
     """
 
     # XXX: See the less filter as to how we might deal with the "needs
@@ -110,12 +119,50 @@ class CompassFilter(Filter):
             sassdir = path.normpath(path.dirname(source_path))
             source_path = path.normpath(source_path)
 
+            # Compass offers some helpers like image-url(), which need
+            # information about the urls under which media files will be
+            # available. This is hard for two reasons: First, the options in
+            # question aren't supported on the command line, so we need to write
+            # a temporary config file. Secondly, the assume a defined and
+            # separate directories for "images", "stylesheets" etc., something
+            # webassets knows nothing of: we don't support the user defining
+            # something such directories. Because we traditionally had this
+            # filter point all type-specific directories to the root media
+            # directory, we will define the paths to match this. In other
+            # words, in Compass, both inline-image("img/test.png) and
+            # image-url("img/test.png") will find the same file, and assume it
+            # to be {env.directory}/img/test.png.
+            # However, this partly negates the purpose of an utiility like
+            # image-url() in the first place - you not having to hard code
+            # the location of your images. So a possiblity for the future
+            # might be adding options that allow changing this behavior (see
+            # ticket #36).
+            #
+            # Note that is also the --relative-assets option, which we can't
+            # use because it calculates an actual relative path between the
+            # image and the css output file, the latter being in a temporary
+            # directory in our case.
+            config_file = path.join(tempout, '.config.rb')
+            f = open(config_file, 'w')
+            try:
+                f.write("""
+http_path = "%s"
+http_images_dir = ""
+http_stylesheets_dir = ""
+http_fonts_dir = ""
+http_javascripts_dir = ""
+    """ % self.env.url)
+                f.flush()
+            finally:
+                f.close()
+
             command = [self.compass, 'compile']
             for plugin in self.plugins:
                 command.extend(('--require', plugin))
             command.extend(['--sass-dir', sassdir,
                             '--css-dir', tempout,
-                            '--image-dir', self.env.url[1:],
+                            '--image-dir', self.env.directory,
+                            '--config', config_file,
                             '--quiet',
                             '--boring',
                             '--output-style', 'expanded',
@@ -132,8 +179,8 @@ class CompassFilter(Filter):
             # compass seems to always write a utf8 header? to stderr, so
             # make sure to not fail just because there's something there.
             if proc.returncode != 0:
-                raise Exception(('compass: subprocess had error: stderr=%s, '+
-                                'stdout=%s, returncode=%s') % (
+                raise FilterError(('compass: subprocess had error: stderr=%s, '+
+                                   'stdout=%s, returncode=%s') % (
                                                 stderr, stdout, proc.returncode))
 
 
@@ -148,4 +195,4 @@ class CompassFilter(Filter):
             # Restore previous working dir
             os.chdir(old_wd)
             # Clean up the temp dir
-            shutil.rmtree(tempout)
\ No newline at end of file
+            shutil.rmtree(tempout)
