@@ -2,11 +2,20 @@
 """
 
 import os
+import urllib2
 try:
     import cStringIO as StringIO
 except:
     import StringIO
-from cache import get_cache, make_key
+
+
+import sys
+if sys.version_info >= (2, 5):
+    import hashlib
+    md5_constructor = hashlib.md5
+else:
+    import md5
+    md5_constructor = md5.new
 
 
 __all__ = ('FileHunk', 'MemoryHunk', 'make_url', 'merge', 'apply_filters')
@@ -20,7 +29,13 @@ class BaseHunk(object):
         raise NotImplementedError()
 
     def key(self):
-        return make_key(self.data())
+        """Return a key we can use to cache this hunk.
+        """
+        # MD5 is faster than sha, and we don't care so much about collisions.
+        # We care enough however not to use hash().
+        md5 = md5_constructor()
+        md5.update(self.data())
+        return md5.hexdigest()
 
     def data(self):
         raise NotImplementedError()
@@ -44,6 +59,23 @@ class FileHunk(BaseHunk):
             f.close()
 
 
+class UrlHunk(BaseHunk):
+    """Represents a file that is referenced by an Url.
+    """
+
+    def __init__(self, url):
+        self.url = url
+
+    def data(self):
+        if not hasattr(self, '_data'):
+            r = urllib2.urlopen(self.url)
+            try:
+                self._data = r.read()
+            finally:
+                r.close()
+        return self._data
+
+
 class MemoryHunk(BaseHunk):
     """Content that is no longer a direct representation of
     a source file. It might have filters applied, and is probably
@@ -54,9 +86,6 @@ class MemoryHunk(BaseHunk):
         self._data = data
         self.files = files
 
-    def key(self):
-        return hash(self._data)
-
     def mtime(self):
         pass
 
@@ -81,10 +110,15 @@ def merge(hunks):
     return MemoryHunk("\n".join([h.data() for h in hunks]))
 
 
-def apply_filters(hunk, filters, type, cache=None, **kwargs):
+def apply_filters(hunk, filters, type, cache=None, no_cache_read=False,
+                  **kwargs):
     """Apply the given list of filters to the hunk, returning a new
     ``MemoryHunk`` object.
 
+    If ``no_cache_read`` is given, then the cache will not be
+    considered for this operation (though the result will still be
+    written to the cache).
+
     ``kwargs`` are options that should be passed along to the filters.
     If ``hunk`` is a file hunk, a ``source_path`` key will automatically
     be added to ``kwargs``.
@@ -98,10 +132,11 @@ def apply_filters(hunk, filters, type, cache=None, **kwargs):
         return hunk
 
     if cache:
-        key = make_key(hunk.key(), filters, type)
-        content = cache.get(key)
-        if not content in (False, None):
-            return MemoryHunk(content)
+        key = ("hunk", hunk.key(), tuple(filters), type)
+        if not no_cache_read:
+            content = cache.get(key)
+            if not content in (False, None):
+                return MemoryHunk(content)
 
     kwargs = kwargs.copy()
     if hasattr(hunk, 'filename'):
@@ -171,6 +206,10 @@ def merge_filters(filters1, filters2):
     are always removed from the second filter set if they exist in the
     first.
 
+    The result will always be ``filters1``, with additional unique
+    filters from ``filters2`` appended. Within the context of a
+    hierarchy, you want ``filters2`` to be the parent.
+
     This function presumes that all the given filters inherit from
     ``Filter``, which properly implements operators to determine
     duplicate filters.
