@@ -4,7 +4,9 @@ import logging
 from optparse import OptionParser
 
 from webassets.loaders import PythonLoader
-from webassets.bundle import BuildError
+from webassets.bundle import get_all_bundle_files
+from webassets.exceptions import BuildError
+from webassets.updater import TimestampUpdater
 
 
 class CommandError(Exception):
@@ -38,15 +40,16 @@ class CommandLineEnvironment():
     def rebuild(self):
         """Rebuild all assets now.
         """
-        for bundle in self.environment:
-            # TODO: Both the build() and the watch() command (and possibly
-            # others in the future) need to go through the motions of
-            # looping over iterbuild(). Can be move this to the environment?
-            for to_build in bundle.iterbuild():
-                self.log.info("Building asset: %s" % to_build.output)
-                try:
-                    to_build.build(force=True)
-                except BuildError, e:
+        if self.environment.debug != False:
+            self.log.warning(
+                ("Current debug option is '%s'. Building as "
+                 "if in production (debug=False)") % self.environment.debug)
+            self.environment.debug = False
+        for to_build in self.environment:
+            self.log.info("Building bundle: %s" % to_build.output)
+            try:
+                to_build.build(force=True)
+            except BuildError, e:
                     self.log.error("Failed, error was: %s" % e)
 
     def watch(self):
@@ -58,20 +61,18 @@ class CommandLineEnvironment():
         _win = (sys.platform == "win32")
         def check_for_changes():
             changed_bundles = []
-            for possibly_container in self.environment:
-                for bundle in possibly_container.iterbuild():
-                    for filename in bundle.get_files():
-                        filename = bundle.env.abspath(filename)
-                        stat = os.stat(filename)
-                        mtime = stat.st_mtime
-                        if _win:
-                            mtime -= stat.st_ctime
+            for bundle in self.environment:
+                for filename in get_all_bundle_files(bundle):
+                    stat = os.stat(filename)
+                    mtime = stat.st_mtime
+                    if _win:
+                        mtime -= stat.st_ctime
 
-                        if _mtimes.get(filename, mtime) != mtime:
-                            changed_bundles.append(bundle)
-                            _mtimes[filename] = mtime
-                            break
+                    if _mtimes.get(filename, mtime) != mtime:
+                        changed_bundles.append(bundle)
                         _mtimes[filename] = mtime
+                        break
+                    _mtimes[filename] = mtime
             return changed_bundles
 
         try:
@@ -80,7 +81,10 @@ class CommandLineEnvironment():
                 changed_bundles = check_for_changes()
                 for bundle in changed_bundles:
                     self.log.info("Rebuilding asset: %s" % bundle.output)
-                    bundle.build(force=True)
+                    try:
+                        bundle.build(force=True)
+                    except BuildError, e:
+                        print "Failed: %s" % e
                 time.sleep(0.1)
         except KeyboardInterrupt:
             pass
@@ -99,14 +103,34 @@ class CommandLineEnvironment():
                 os.unlink(file_path)
                 self.log.info("Deleted asset: %s" % bundle.output)
 
+    def check(self):
+        """Check to see if assets need to be rebuilt.
+
+        A non-zero exit status will be returned if any of the input files are
+        newer (based on mtime) than their output file. This is intended to be
+        used in pre-commit hooks.
+        """
+        needsupdate = False
+        updater = self.environment.updater
+        if not updater:
+            self.log.debug('no updater configured, using TimestampUpdater')
+            updater = TimestampUpdater()
+        for bundle in self.environment:
+            self.log.info('Checking asset: %s', bundle.output)
+            if updater.needs_rebuild(bundle, self.environment):
+                self.log.info('  needs update')
+                needsupdate = True
+        if needsupdate:
+            sys.exit(-1)
+
     # List of command methods
     Commands = {
         'rebuild': rebuild,
         'watch': watch,
         'clean': clean,
+        'check': check,
     }
 
-
 def main(argv, env=None):
     """Generic version of the command line utilities, not specific to
     any framework.
@@ -156,4 +180,4 @@ def run():
 
 
 if __name__ == '__main__':
-    run()
\ No newline at end of file
+    run()
